# TCRanno
Qualitative and Quantitative Annotations of T-Cell Receptor (TCR) Repertoire Specificity

## Requirements
Python>=3.7.6 \
tensorflow>=2.4.1, levenshtein, pandas, matplotlib, comut, palettable

## Installation
```
pip3 install tensorflow levenshtein pandas comut palettable
pip3 install tcranno
```
## Usage

Please refer to the github page: https://github.com/deepomicslab/TCRanno
